package cn.feast.coding.service.stock;

import cn.feast.coding.model.stock.StockAnalyse;
import cn.feast.coding.service.IService;
import com.github.pagehelper.PageInfo;

import java.util.List;
import java.util.Map;

public interface StockAnalyseService extends IService<StockAnalyse> {
    PageInfo<Map<String, Object>> queryAnalyse(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> queryAnalyse1(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> queryAnalyse2(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> sortByTurn(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> sortByPrice(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> querySentiment(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> queryConcept(StockAnalyse stockAnalyse, int pageNum, int pageSize);

    PageInfo<Map<String, Object>> queryStockConcept(String stockCode, int pageNum, int pageSize);

    List<Map<String, Object>> queryConceptStocks(String conceptName);

    List<Map<String, Object>> getKLineData(String stockCode);
}
